@@ -9,6 +9,7 @@ import logging
 from hein_control.action import (Action, ConfiguredAction, ActionList,
                                  ConfiguredActionList, TrackedActionList, TrackedAction)
 from hein_control.sequencing import ExecutionSequence, ConfiguredSequence
+from hein_control.mixin import is_jsonable
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
@@ -33,6 +34,11 @@ def error():
     raise ValueError('something has gone horrible wrong! (intentionally)')
 
 
+def as_dict_serializable(action) -> bool:
+    """verifies that the as_dict representation is serializable"""
+    return is_jsonable(action.as_dict())
+
+
 class TestLists(unittest.TestCase):
     def test_action_list(self):
         """tests the ActionList class"""
@@ -97,8 +103,11 @@ class TestExecSequence(unittest.TestCase):
 
     def test_execution(self):
         """tests execution of sequences"""
+        self.assertTrue(as_dict_serializable(self.tracked))
         self.tracked()
+        self.assertTrue(as_dict_serializable(self.tracked))
         self.tracked.wait_for_completion()
+        self.assertTrue(as_dict_serializable(self.tracked))
         for attr in self.attrs:
             self.assertIsNotNone(
                 getattr(self.tracked, attr)
